@@ -1,18 +1,26 @@
 import json
 from cgi import parse_header
 from io import BytesIO
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Dict, Optional, Tuple, Union, Callable
 
 import yaml
 
 from .http_headers import HttpHeaders
-from .http_message import FormHttpMessage, HttpMessage, JsonHttpMessage, MultipartHttpMessage, YamlHttpMessage
+from .http_message import (
+    FormHttpMessage,
+    HttpMessage,
+    JsonHttpMessage,
+    MultipartHttpMessage,
+    YamlHttpMessage,
+    SimpleHttpMessage,
+)
 
 
 class HttpParsedBodyTrait:
     _body: BytesIO
     _headers: HttpHeaders
     _parsed_body: Optional[Union[HttpMessage, Any]]
+    _parsed_body_getter: Optional[Callable]
     _as_str: Optional[str]
     _as_dict: Optional[dict]
 
@@ -21,6 +29,10 @@ class HttpParsedBodyTrait:
         if self._parsed_body:
             return self._parsed_body
 
+        if hasattr(self, "_parsed_body_getter"):
+            self._parsed_body = self._parsed_body_getter()  # type: ignore
+            return self._parsed_body
+
         content_type: Tuple[str, Dict[str, str]] = parse_header(
             self._headers["Content-Type"]  # type: ignore
         )
@@ -29,7 +41,7 @@ class HttpParsedBodyTrait:
 
         if content_type[0] == "multipart/form-data":
             parsed_body = MultipartHttpMessage.from_bytes(
-                self._body, content_type[1].get("boundary", ""), content_type[1].get("charset", ""),
+                self._body, content_type[1].get("boundary", ""), content_type[1].get("charset", "utf8"),
             )
         elif content_type[0] == "application/x-www-form-urlencoded":
             parsed_body = FormHttpMessage.from_bytes(self._body, content_type[1].get("charset", "utf8"))
@@ -40,7 +52,7 @@ class HttpParsedBodyTrait:
             parsed_body = YamlHttpMessage.from_bytes(self._body, content_type[1].get("charset", "utf8"))
         else:
             self._body.seek(0)
-            parsed_body = HttpMessage(self._body.read().decode(content_type[1].get("charset", "utf8")))
+            parsed_body = SimpleHttpMessage(self._body.read().decode(content_type[1].get("charset", "utf8")))
 
         self._parsed_body = parsed_body
         return self._parsed_body
